Python: module AIGO.Similarity

AIGO.Similarity | index /home/dpm/projects/AIGO-0.1.0/AIGO/Similarity.py

`Similarity.py
AIGO is a python library for
the Analysis and Inter-comparison of Gene Ontology functional annotations.
see (http://code.google.com/p/aigo).
Created by Michael Defoin-Platel on 21/02/2010.
Copyright (c) 2010. All rights reserved.
AIGO is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.`

Functions
`` |  | GOSet_PWSimilarity(G, GO1, GO2, metric='GS2', **kargs) `Calculates pairwise semantic similarity scores between two given annotation sets` GOSet_Similarity(G, GO, metric='GS2', **kargs) `Calculates pairwise semantic similarity scores between GO terms in a given annotation set` GO_Similarity(G, allGO, metric='GS2', **kargs) `Calculates pairwise semantic similarity scores in a list of annotation sets`

Data
`` |  | logger = <AIGO.utils.Logger.Logger instance at 0xb7547bac>